@@ -1,5 +1,5 @@
 package App::TeleGramma::Plugin::Base;
-$App::TeleGramma::Plugin::Base::VERSION = '0.04';
+$App::TeleGramma::Plugin::Base::VERSION = '0.05';
 # ABSTRACT: Base class for TeleGramma plugins
 
 use Mojo::Base -base;
@@ -12,6 +12,7 @@ has 'app_config';
 has 'app';
 has '_store';
 
+
 sub truncated_package_name {
   my $self = shift;
   my $package = ref($self);
@@ -19,6 +20,7 @@ sub truncated_package_name {
   return $package;
 }
 
+
 sub short_name {
   my $self = shift;
   my $package = ref($self);
@@ -28,6 +30,7 @@ sub short_name {
   return "plugin-" . $package;
 }
 
+
 # override: optional
 sub default_config { {} }
 
@@ -36,12 +39,12 @@ sub check_prereqs {
   1;
 }
 
-# override: optional but HIGHLY RECOMMENDED
+
 sub synopsis {
   "My author did not provide a synopsis!";
 }
 
-# override: REQUIRED
+
 sub register {
   my $self = shift;
   die ref($self) .  " did not supply a register method\n";
@@ -60,6 +63,7 @@ sub create_default_config_if_necessary {
   }
 }
 
+
 sub read_config {
   my $self = shift;
   my $section = $self->short_name();
@@ -67,6 +71,7 @@ sub read_config {
   return $self->app_config->config->{$section} || {};
 }
 
+
 sub reply_to {
   my $self  = shift;
   my $msg   = shift;
@@ -77,6 +82,7 @@ sub reply_to {
   $app->send_message_to_chat_id($msg->chat->id, $reply);
 }
 
+
 sub data_dir {
   my $self = shift;
   my $data_dir = catdir($self->app_config->path_plugin_data, $self->short_name);
@@ -84,6 +90,7 @@ sub data_dir {
   return $data_dir;
 }
 
+
 sub store {
   my $self = shift;
   return $self->_store if ($self->_store);
@@ -111,7 +118,54 @@ App::TeleGramma::Plugin::Base - Base class for TeleGramma plugins
 
 =head1 VERSION
 
-version 0.04
+version 0.05
+
+=head1 METHODS
+
+=head2 truncated_package_name
+
+Provide the name of the plugin, in perl form (hierarchy delimited with '::')
+but without the leading C<App::TeleGramma::Plugin>.
+
+=head2 short_name
+
+Provide the name of the plugin, with the '::' separators changed to '-', and
+the leading 'App::TeleGramma::Plugin::' removed.
+
+=head2 default_config
+
+Override this method in your subclass if you want to provide a default
+configuration for your plugin (apart from the "enabled" flag).
+
+=head2 synopsis
+
+Override this method to provide a one-line synopsis of your plugin.
+
+=head2 register
+
+Override this method to register your plugin. It must setup any required
+listeners. See L<App::TeleGramma::Plugin::Core::Fortune> for an example.
+
+=head2 read_config
+
+Read the configuration specific to this plugin.
+
+Returns a hashref
+
+=head2 reply_to
+
+Reply to a message, with text.
+
+Should be provided the Telegram::Bot::Message object, and the text string
+to respond with.
+
+=head2 data_dir
+
+Returns the path on disk that your plugin should store any data.
+
+=head2 store
+
+Returns an L<App::TeleGramma::Store> object for you to persist your plugin data.
 
 =head1 AUTHOR
 
