@@ -1,5 +1,5 @@
 package App::TeleGramma::Plugin::Core::Stenographer;
-$App::TeleGramma::Plugin::Core::Stenographer::VERSION = '0.04';
+$App::TeleGramma::Plugin::Core::Stenographer::VERSION = '0.05';
 # ABSTRACT: TeleGramma plugin to log all text messages
 
 use Mojo::Base 'App::TeleGramma::Plugin::Base';
@@ -46,8 +46,16 @@ sub log_message {
   return PLUGIN_NO_RESPONSE unless $msg->text;  # don't try to deal with anything but text
 
   my $fh = $self->log_fh_for_message($msg);
-  my $username = 'unknown';
-  $username = $msg->from->username if ($msg->from);
+  my $username;
+  if ($msg->from && $msg->from->username) {
+    $username = $msg->from->username;
+  }
+  elsif ($msg->from) {
+    $username = $msg->from->id;
+  }
+  else {
+    $username = "unknown";
+  }
 
   my $text = sprintf("%-26s %s: %s\n", scalar localtime, $username, $msg->text);
   print $fh $text;
@@ -70,7 +78,7 @@ App::TeleGramma::Plugin::Core::Stenographer - TeleGramma plugin to log all text
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 AUTHOR
 
