@@ -1,7 +1,8 @@
 package App::TeleGramma::Store;
-$App::TeleGramma::Store::VERSION = '0.04';
+$App::TeleGramma::Store::VERSION = '0.05';
 # ABSTRACT: Persistent datastore for TeleGramma and plugins
 
+
 use Mojo::Base -base;
 use Storable qw/store retrieve/;
 use Carp qw/croak/;
@@ -10,6 +11,7 @@ use File::Spec::Functions qw/catfile/;
 has 'path';
 has 'dbs' => sub { {} };
 
+
 sub hash {
   my $self = shift;
   my $db   = shift || die "no db?";
@@ -50,6 +52,7 @@ sub read_db_into_hash {
   return retrieve($db_file);
 }
 
+
 sub save {
   my $self = shift;
   my $db   = shift;
@@ -58,6 +61,7 @@ sub save {
   store($self->hash($db), $db_file);
 }
 
+
 sub save_all {
   my $self = shift;
   my @dbs = keys %{ $self->dbs };
@@ -78,7 +82,42 @@ App::TeleGramma::Store - Persistent datastore for TeleGramma and plugins
 
 =head1 VERSION
 
-version 0.04
+version 0.05
+
+=head1 SYNOPSIS
+
+  my $store = App::TeleGramma::Store->new(path => "/some/dir");
+  my $hashref1 = $store->hash('mydata-1');
+  $hashref1->{foo} = 'bar';
+  $hashref1->{bar} = 'baz';
+  $store->save('mydata-1');  # persisted
+
+  my $hashref2 = $store->hash('mydata-2'); # new data structure
+  $hashref2->{users} = [ qw/ a b c / ];
+
+  $store->save_all;  # persist data in both the 'mydata1' hash and the 'mydata2' hash
+
+=head1 METHODS
+
+=head2 hash
+
+Return the hash reference for a named entry in your data store. Note that
+the names become disk filenames, and thus must consist of alphanumeric characters
+or '-' only.
+
+=head2 save
+
+Save a named hash to the data store.
+
+References are saved using L<Storable> and the limitations in terms of data
+stored can be found in that documenation.
+
+In general, if you stick with simple hashrefs, arrayrefs and scalars you will
+be fine.
+
+=head2 save_all
+
+Persist all named hashrefs to the store at once.
 
 =head1 AUTHOR
 
